#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['briar_repl']

package_data = \
{'': ['*']}

setup(name='briar_repl',
      version='19.12.15',
      description='briar cli-messenger for briar:headless',
      author='fphemeral',
      author_email='fphemeral@i2pmail.org',
      url='https://code.briarproject.org/fphemeral/briar_repl',
      packages=packages,
      package_data=package_data,
     )
